# nshmp-ws

## Running the Services

### Gradle

To run the services with Gradle:

```bash
./gradlew run
```

Services are then avialable on <http://localhost:8080/>

To have the services automatically recompile when changes are made locally to the source
code, run:

```bash
./gradlew run -t
```

### Jar file

The services can be run from the JAR file:

```bash
./gradlew assemble
java -jar build/libs/nshmp-ws-all.jar
```

Services are then avialable on <http://localhost:8080/>

Note: By default the web services use the
[nshm-fault-sections](https://code.usgs.gov/ghsc/nshmp/nshm-fault-sections) repository in the `libs`
directory in the root of this project and such the `java -jar` command should also be run
in the root of the project. To run the JAR file from anywhere the path to the fault sections
should be specified:

```bash
./gradlew assemble
java -jar path/to/nshmp-ws-all.jar --faults-path=path/to/nshm-fault-sections
```

### Docker

### Run from GitLab Registry

The nshmp-ws application may be run as a Docker container.

```bash
docker pull code.chs.usgs.gov:5001/ghsc/nshmp/images/nshmp-ws
docker run \
    -p <PORT>:8080 \
    code.chs.usgs.gov:5001/ghsc/nshmp/images/nshmp-ws

# Example
docker run \
    -p 8080:8080 \
    code.chs.usgs.gov:5001/ghsc/nshmp/images/nshmp-ws
```

`PORT` should be replaced with an available port that is not in use. The application
can then be accessed from:

```bash
http://localhost:PORT/nshmp/data
http://localhost:PORT/nshmp/data/fault-sections

# Example
http://localhost:8080/nshmp/data
http://localhost:8080/nshmp/data/fault-sections
```

The `PORT` should be replaced with the same value to start the container.

### Build Docker Locally

A Docker image can also be created locally:

```bash
docker build \
    --build-arg git_username=<GitLab Email> \
    --build-ard git_password=<GitLab Access Token> \
    -t <tag name> .
```

Where:

* `git_username` is the GitLab Email
* `git_password` is a [GitLab access token](https://docs.gitlab.com/ee/user/profile/personal_access_tokens.html#creating-a-personal-access-token)
with at minimum read access.

## Fault Sections Service

### Fault Sections Service: Usage

* /nshmp/data/fault-sections

### Obtaining fault sections

See [nshm-fault-sections](https://code.usgs.gov/ghsc/nshmp/nshm-fault-sections)
for information on groups and ids.

#### By Group

* Format: /nshmp/data/fault-sections?group={String}&raw={Boolean}
* Format: /nshmp/data/{group}/{raw}
* Example: /nshmp/data/fault-sections?group=CA
* Example: /nshmp/data/fault-sections?group=CA&group=NV&group=...
* Example: /nshmp/data/fault-sections/CA

Where `group` can either be a
[`UsRegion`](https://earthquake.usgs.gov/nshmp/docs/nshmp-lib/gov/usgs/earthquake/nshmp/internal/UsRegion.html)
or [`FaultGroup`](https://code.usgs.gov/ghsc/nshmp/nshmp-ws/-/blob/main/src/main/java/gov/usgs/earthquake/nshmp/www/fault/FaultGroup.java).

By default the `raw` flag is set to `false`, when set to `true` the response is pure GeoJSON

#### By ID

* Format: /nshmp/data/fault-sections?id={Integer}&raw={Boolean}
* Example: /nshmp/data/fault-sections?id=1
* Example: /nshmp/data/fault-sections?id=1&id=2&id=...

* Format: /nshmp/data/fault-sections/{id}/{raw}
* Example: /nshmp/data/fault-sections/1

### Local Development

The [fault sections repository](https://code.usgs.gov/ghsc/nshmp/nshm-fault-sections)
repository is downloaded from a tagged version, see [gradle.properties](gradle.properties)
`nshmFaultSectionsTag` for tagged version used, and stored in the libs directory.

To, instead, point to a local version of the fault sections repository update the
gradle.properties file, either in this project or under `$GRADLE_USER_HOME`/gradle.properties
(defaults to `$USER_HOME/.gradle`), with the following:

```bash
faultSectionsEnv = DEV
```

Run `./gradlew clean` to clean up the libs directory and make a symbolinc link from the
fault sections repository to the libs directory.
Example:

```bash
cd libs
ln -s ../nshm-fault-sections .
```

## GPS Data Service

GPS data service provides access to the GPS datasets used for each NSHM. All velocities are
in units of mm/yr and the vertical component, if available, is positive up.

### GPS Data Service: Usage

Datasets are selected by model:

* `CONUS_2014_UCERF`
* `CONUS_2014_WUS`
* `AK_2020`
* `HI_2020`

Data format is one of the following:

* `CSV` (default)
* `JSON` (GeoJSON feature collection embedded in JSON response)
* `RAW_JSON` (GeoJSON feature collection)

#### GPS Data: Query-based

* Format: /nshmp/data/gps?model={MODEL}&format={FORMAT}
* Example: /nshmp/data/gps?model=HI_2020&format=CSV

#### GPS Data: Slash-delimited based

* Format: /nshmp/data/gps/{MODEL}/{FORMAT}
* Example: /nshmp/data/gps/HI_2020/JSON

### Geodesy Process

TODO: expand process description

* In house multi-modeling capability
* Curate/update strain vector fields
* Connectivity in fault models
* Data transfer
  * Modifications to fault models required by geodetic modelers need to be communicated back to NSHM
* slip rate uncertainties
