package gov.usgs.earthquake.nshmp.www;

import io.micronaut.context.ApplicationContext;
import io.micronaut.http.HttpRequest;
import io.micronaut.runtime.Micronaut;
import io.swagger.v3.oas.annotations.OpenAPIDefinition;
import io.swagger.v3.oas.annotations.info.Info;

@OpenAPIDefinition(
    info = @Info(
        title = "NSHMP Non-NSHM Services",
        description = "### Services not related to a National Seismic Hazard Model:\n" +
            "* Fault Sections: Get fault sections in GeoJSON form\n" +
            "* Geodesy: Get GPS data sets for NSHM\n" +
            "* Ground Motion Model: Get response spectra and ground motion Vs. distance, " +
            "and ground motion Vs. magnitude\n" +
            "* Gulf: Get gulf coast sediment depth data"))
public class Application {

  public static void main(String[] args) {
    ApplicationContext app = Micronaut.build(args)
        .mainClass(Application.class)
        .start();

    initFaultSections(app);
    initGps(app);
    initGulf(app);
  }

  /* Call usage to load nshm-fault-sections */
  private static void initFaultSections(ApplicationContext app) {
    FaultSectionsController cont = app.createBean(FaultSectionsController.class);
    cont.doGetFaults(HttpRequest.GET(""), null, null, null, null, null);
  }

  /* Call usage to load GPS data */
  private static void initGps(ApplicationContext app) {
    GpsController cont = app.createBean(GpsController.class);
    cont.doGetGpsData(HttpRequest.GET(""), null, null);
  }

  /* Call usage to load Gulf data */
  private static void initGulf(ApplicationContext app) {
    GulfController cont = app.createBean(GulfController.class);
    Double dbl = null;
    cont.doGetGulf(HttpRequest.GET(""), dbl, dbl);
  }

}
