package gov.usgs.earthquake.nshmp.www;

import gov.usgs.earthquake.nshmp.www.services.UtilitiesService;

import io.micronaut.http.HttpRequest;
import io.micronaut.http.HttpResponse;
import io.micronaut.http.annotation.Controller;
import io.micronaut.http.annotation.Get;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.inject.Inject;

@Tag(name = "Utilities",
    description = "Utility Services")
@Controller("/util")
public class UtilitiesController {

  @Inject
  private NshmpMicronautServlet servlet;

  /**
   * GET method to return the test sites as a feature collections.
   *
   * @param request The HTTP request
   */
  @Operation(
      summary = "Returns the test sites",
      operationId = "util_doGetTestSites",
      description = "Returns a GeoJSON feature collection of the test sites")
  @ApiResponse(
      description = "The test sites",
      responseCode = "200",
      content = @Content(
          schema = @Schema(type = "string")))
  @Get(uri = "/testsites")
  public HttpResponse<String> doGetTestSites(HttpRequest<?> request) {
    return UtilitiesService.handleDoGetSites(request);
  }

}
