package gov.usgs.earthquake.nshmp.www.gmm;

import java.util.ArrayList;
import java.util.List;

import gov.usgs.earthquake.nshmp.data.XySequence;

/*
 * XY data sequences serialization object.
 *
 * @author U.S. Geological Survey
 */
@SuppressWarnings("unused")
class XyDataGroup {

  private final String label;
  private final String xLabel;
  private final String yLabel;
  private final List<Series> data;

  private XyDataGroup(String label, String xLabel, String yLabel) {
    this.label = label;
    this.xLabel = xLabel;
    this.yLabel = yLabel;
    this.data = new ArrayList<>();
  }

  /* Create a data group. */
  static XyDataGroup create(String name, String xLabel, String yLabel) {
    return new XyDataGroup(name, xLabel, yLabel);
  }

  /* Add a data sequence */
  XyDataGroup add(String id, String name, XySequence data, List<EpiSeries> tree) {
    this.data.add(new Series(id, name, data, tree));
    return this;
  }

  static class Series {

    private final String id;
    private final String label;
    private final XySequence data;
    private final List<EpiSeries> tree;

    Series(String id, String label, XySequence data, List<EpiSeries> tree) {
      this.id = id;
      this.label = label;
      this.data = data;
      this.tree = tree;
    }
  }

  static class EpiSeries {

    final String id;
    final double[] values;
    final double[] weights;

    EpiSeries(String id, double[] values, double[] weights) {
      this.id = id;
      this.values = values;
      this.weights = weights;
    }
  }

}
