package gov.usgs.earthquake.nshmp.www.gps;

import static com.google.common.base.CaseFormat.LOWER_HYPHEN;
import static com.google.common.base.CaseFormat.UPPER_UNDERSCORE;

import java.util.Arrays;

import io.micronaut.core.annotation.Introspected;

/**
 *
 * @author U.S. Geological Survey
 */
@Introspected
public enum GpsDataSet {

  AK_2020(
      "Alaska 2020",
      "ak_2020.csv"),

  HI_2020(
      "Hawaii 2020",
      "hi_2020.csv"),

  CONUS_2014_WUS(
      "CONUS 2014 WUS",
      "conus_2014_wus.csv"),
  CONUS_2014_UCERF(
      "CONUS 2014 UCERF",
      "conus_2014_ucerf.csv"),

  CONUS_2023(
      "CONUS 2023",
      "conus_2023.csv");

  public final String label;
  public final String id;
  public String filename;

  private GpsDataSet(String label, String filename) {
    this.label = label;
    this.filename = filename;
    id = toId();
  }

  @Override
  public String toString() {
    return label;
  }

  public String toId() {
    return UPPER_UNDERSCORE.to(LOWER_HYPHEN, name());
  }

  /**
   * Returns a GpsDataSet with specified id.
   *
   * @param id The id of the dataSet
   */
  public static GpsDataSet fromId(String id) {
    return Arrays.asList(values()).stream()
        .filter(dataSet -> dataSet.id.equals(id))
        .findFirst()
        .orElseThrow(() -> new IllegalArgumentException("GpsDataSet [" + id + "] not found"));
  }

}
