package gov.usgs.earthquake.nshmp.www.gps;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import com.google.common.base.Joiner;
import com.google.gson.JsonElement;

import gov.usgs.earthquake.nshmp.Text;
import gov.usgs.earthquake.nshmp.geo.json.FeatureCollection;

/**
 * Read in all GPS data sets from data directory and store CSV and JSON string
 * representations.
 *
 * @author U.S. Geological Survey
 */
public class GpsDataSets {

  private Map<GpsDataSet, String> gpsDataSetsCsv;
  private Map<GpsDataSet, FeatureCollection> gpsDataSetsJson;

  private GpsDataSets(
      Map<GpsDataSet, String> gpsDataSetsCsv,
      Map<GpsDataSet, FeatureCollection> gpsDataSetsJson) {
    this.gpsDataSetsCsv = gpsDataSetsCsv;
    this.gpsDataSetsJson = gpsDataSetsJson;
  }

  public static GpsDataSets loadGpsDataSets() {
    Map<GpsDataSet, String> mapCsv = new HashMap<>();
    Map<GpsDataSet, FeatureCollection> mapFc = new HashMap<>();

    for (GpsDataSet gpsDataSet : GpsDataSet.values()) {
      GpsData gpsData = GpsData.readGpsData(gpsDataSet);
      // build string of lines, append newline at EOF
      String csv = Joiner.on(Text.NEWLINE).skipNulls().join(gpsData.originalLines()) + Text.NEWLINE;
      mapCsv.put(gpsDataSet, csv);
      mapFc.put(gpsDataSet, gpsData.asFeatureCollection());
    }
    return new GpsDataSets(Collections.unmodifiableMap(mapCsv), Collections.unmodifiableMap(mapFc));
  }

  public String getCsv(GpsDataSet gpsDataSet) {
    return gpsDataSetsCsv.get(gpsDataSet);
  }

  public String getJsonString(GpsDataSet gpsDataSet) {
    return gpsDataSetsJson.get(gpsDataSet).toJson();
  }

  public JsonElement getJsonTree(GpsDataSet gpsDataSet) {
    return gpsDataSetsJson.get(gpsDataSet).toJsonTree();
  }

}
