package gov.usgs.earthquake.nshmp.www.services;

import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.AK;
import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.CEUS;
import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.CONUS;
import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.FACILITIES;
import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.HAWAII;
import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.NERP;
import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.NRC;
import static gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion.WUS;

import java.util.EnumSet;
import java.util.Map;
import java.util.TreeMap;

import gov.usgs.earthquake.nshmp.geo.json.Feature;
import gov.usgs.earthquake.nshmp.geo.json.GeoJson;
import gov.usgs.earthquake.nshmp.geo.json.Properties;
import gov.usgs.earthquake.nshmp.www.Utils;
import gov.usgs.earthquake.nshmp.www.site.NshmpSite;
import gov.usgs.earthquake.nshmp.www.site.NshmpSiteRegion;

import io.micronaut.http.HttpRequest;
import io.micronaut.http.HttpResponse;
import jakarta.inject.Singleton;

/**
 * Service handler for {@code UtilitiesController}.
 *
 * @author U.S. Geological Survey
 */
@Singleton
public class UtilitiesService {

  private static final String SERVICE_NAME = "Test Sites Service";
  private static String TEST_SITES = null;

  public static HttpResponse<String> handleDoGetSites(HttpRequest<?> request) {
    try {
      setTestSites();
      return HttpResponse.ok(TEST_SITES);
    } catch (Exception e) {
      return Utils.handleError(e, SERVICE_NAME, request.getUri().getPath());
    }
  }

  private static void setTestSites() {
    if (TEST_SITES == null) {
      TEST_SITES = proccessTestSites();
    }
  }

  private static String proccessTestSites() {
    var nshmpSites = new TreeMap<NshmpSiteRegion, EnumSet<NshmpSite>>();
    nshmpSites.put(AK, NshmpSite.alaska());
    nshmpSites.put(CEUS, NshmpSite.ceus());
    nshmpSites.put(CONUS, NshmpSite.conus());
    nshmpSites.put(FACILITIES, NshmpSite.facilities());
    nshmpSites.put(HAWAII, NshmpSite.hawaii());
    nshmpSites.put(NERP, NshmpSite.nehrp());
    nshmpSites.put(NRC, NshmpSite.nrc());
    nshmpSites.put(WUS, NshmpSite.wus());

    var builder = GeoJson.builder();

    for (var region : nshmpSites.keySet()) {
      for (var site : nshmpSites.get(region)) {
        Map<String, Object> properties = Properties.builder()
            .put(Key.TITLE, site.toString())
            .put(Key.REGION_ID, region.name())
            .put(Key.REGION_TITLE, region.display)
            .build();

        builder.add(Feature.point(site.location())
            .id(site.name())
            .properties(properties)
            .build());
      }
    }
    return builder.build().toJson();
  }

  private static class Key {
    private static final String TITLE = "title";
    private static final String REGION_ID = "regionId";
    private static final String REGION_TITLE = "regionTitle";
  }

}
