package gov.usgs.earthquake.nshmp.www;

import static gov.usgs.earthquake.nshmp.www.Utils.GSON;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

import java.lang.reflect.Type;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.ArgumentsSource;

import com.google.common.reflect.TypeToken;
import com.google.gson.JsonElement;

import gov.usgs.earthquake.nshmp.geo.Location;
import gov.usgs.earthquake.nshmp.www.gulf.GulfData.GulfDataResponse;
import gov.usgs.earthquake.nshmp.www.gulf.GulfDataTests.GulfParameterizedTests;
import gov.usgs.earthquake.nshmp.www.meta.Status;
import gov.usgs.earthquake.nshmp.www.services.GulfService.RequestData;

import io.micronaut.http.HttpRequest;
import io.micronaut.test.extensions.junit5.annotation.MicronautTest;
import jakarta.inject.Inject;

@MicronautTest
class GulfControllerTests {

  @SuppressWarnings("serial")
  private static final Type REQUEST_DATA_TYPE =
      new TypeToken<ResponseBody<RequestData, JsonElement>>(ResponseBody.class) {}.getType();

  private HttpRequest<?> request;

  @Inject
  GulfController controller;

  @BeforeEach
  public final void beforeEach() {
    request = HttpRequest.GET("");
  }

  @ParameterizedTest
  @ArgumentsSource(GulfParameterizedTests.class)
  final void httpGulfDataTests(double lon, Double lat, Double depth) {

    var loc = Location.create(lon, lat);

    // Slash delimited HTTP GET test
    var httpSlash = controller.doGetGulfSlash(request, lon, lat);
    httpTests(httpSlash.body(), loc, depth);

    // Query based HTTP GET test
    var http = controller.doGetGulf(request, lon, lat);
    httpTests(http.body(), loc, depth);
  }

  private void httpTests(String http, Location loc, Double depth) {
    ResponseBody<RequestData, JsonElement> response = GSON.fromJson(http, REQUEST_DATA_TYPE);
    var request = response.getRequest();

    var actual = GSON.fromJson(response.getResponse(), GulfDataResponse.class);

    assertEquals(Status.SUCCESS, response.getStatus());
    assertTrue(Status.SUCCESS.equals(response.getStatus()));
    assertNotEquals(Status.ERROR, response.getStatus());

    // requests are for grid points, so no rounding is performed
    assertEquals(loc.longitude, request.longitude);
    assertEquals(loc.latitude, request.latitude);
    assertEquals(loc.longitude, actual.longitude);
    assertEquals(loc.latitude, actual.latitude);
    assertEquals(depth, actual.sedimentDepth);

  }

}
