package gov.usgs.earthquake.nshmp.www.gps;

import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.CORRELATION;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.LATITUDE;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.LONGITUDE;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.SIG_E;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.SIG_N;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.SIG_V;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.SITETYPE;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.STATIONID;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.VEL_E;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.VEL_N;
import static gov.usgs.earthquake.nshmp.www.gps.GpsData.Field.VEL_V;
import static gov.usgs.earthquake.nshmp.www.gps.GpsDataSet.AK_2020;
import static gov.usgs.earthquake.nshmp.www.gps.GpsDataSet.CONUS_2014_UCERF;
import static gov.usgs.earthquake.nshmp.www.gps.GpsDataSet.CONUS_2014_WUS;
import static gov.usgs.earthquake.nshmp.www.gps.GpsDataSet.CONUS_2023;
import static gov.usgs.earthquake.nshmp.www.gps.GpsDataSet.HI_2020;
import static org.junit.jupiter.api.Assertions.assertEquals;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.EnumSource;

class GpsDataTests {

  private static final Map<GpsDataSet, List<String>> fieldMap =
      Map.of(
          HI_2020,
          Arrays.asList(LONGITUDE, LATITUDE, VEL_E, VEL_N, VEL_V, SIG_E, SIG_N, SIG_V),
          AK_2020,
          Arrays.asList(STATIONID, SITETYPE, LONGITUDE, LATITUDE, VEL_E, VEL_N, SIG_E, SIG_N),
          CONUS_2014_UCERF,
          Arrays.asList(LONGITUDE, LATITUDE, VEL_E, VEL_N, SIG_E, SIG_N, CORRELATION),
          CONUS_2014_WUS,
          Arrays.asList(LONGITUDE, LATITUDE, VEL_E, VEL_N, SIG_E, SIG_N, CORRELATION),
          CONUS_2023,
          Arrays.asList(LONGITUDE, LATITUDE, VEL_E, VEL_N, SIG_E, SIG_N, CORRELATION));

  @ParameterizedTest
  @EnumSource(value = GpsDataSet.class,
      names = { "AK_2020", "HI_2020", "CONUS_2014_WUS", "CONUS_2014_UCERF", "CONUS_2023" })
  final void getFieldsTests(GpsDataSet gpsDataSet) {
    GpsData data = GpsData.readGpsData(gpsDataSet);
    List<String> expected = fieldMap.get(gpsDataSet).stream().sorted().collect(Collectors.toList());
    List<String> actual = data.getFields().stream().sorted().collect(Collectors.toList());
    assertEquals(expected, actual);
  }

}
